@@ -11,8 +11,6 @@ const our $ADDRESS_NAME         => 1 << 1;
 const our $ADDRESS_HOUSE_NUMBER => 1 << 2;
 const our $ADDRESS_STREET       => 1 << 3;
 const our $ADDRESS_UNIT         => 1 << 4;
-
-
 const our $ADDRESS_LOCALITY     => 1 << 7;
 const our $ADDRESS_ADMIN1       => 1 << 8;
 const our $ADDRESS_ADMIN2       => 1 << 9;
@@ -24,7 +22,7 @@ const our $ADDRESS_POSTAL_CODE  => 1 << 14;
 const our $ADDRESS_NEIGHBORHOOD => 1 << 15;
 const our $ADDRESS_ALL          => (1 << 16) - 1;
 
-our $VERSION     = '0.06';
+our $VERSION     = '0.07';
 our %EXPORT_TAGS = ( 'all' => [qw/
     expand_address
     parse_address
@@ -47,10 +45,10 @@ our %EXPORT_TAGS = ( 'all' => [qw/
   /]);
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-XSLoader::load('Geo::libpostal', $VERSION);
+XSLoader::load();
 
 # cleanup libpostal
-#END { _teardown() }
+END { _teardown() }
 1;
 __END__
 =encoding utf8
@@ -116,7 +114,7 @@ Takes an address string and returns a list of known variants. Useful for normali
       roman_numerals => 1,
   );
 
-B<Warning>: old versions of libpostal L<segfault|https://github.com/openvenues/libpostal/issues/79> if all options are set to false. This C<Geo::libpostal> includes a unit test for this.
+B<Warning>: old versions of libpostal L<segfault|https://github.com/openvenues/libpostal/issues/79> if all options are set to false. C<Geo::libpostal> includes a unit test for this.
 
 Also accepts an arrayref of language codes per L<ISO 639-1|https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes>:
 
@@ -221,7 +219,14 @@ libpostal is not L<thread-safe|https://github.com/openvenues/libpostal/issues/34
 
 =head1 EXTERNAL DEPENDENCIES
 
-L<libpostal|https://github.com/openvenues/libpostal> is required.
+L<libpostal|https://github.com/openvenues/libpostal> is required. C<Geo::libpostal> uses pkg-config to support custom install locations. Sometimes pkg-config can't find the library by default, in those cases just do:
+
+  $ find / -name libpostal.pc 2>/dev/null
+  /usr/local/lib/pkgconfig/libpostal.pc
+
+  $ export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig
+
+And then do a manual installation of C<Geo::libpostal>.
 
 =head1 INSTALLATION
 
